/**
 * Unified Page Component
 * 
 * A unified component for rendering all types of pages (main, clients, cases)
 * using a consistent block-based content structure.
 * 
 * Features:
 * - Dynamic content loading from API
 * - Fallback content support
 * - Authentication-aware content fetching
 * - Smooth loading transitions
 * - Error handling with user-friendly messages
 * - SEO-friendly structure
 */
import React, { useEffect, useState, useMemo } from 'react';
import { useParams, useLocation } from 'react-router-dom';
import { ContentBlock, renderBlock } from '../components/blocks/BlockRenderer';
import BackLink from '../components/Navigation/BackLink';
import { getFallbackCase } from '../data/fallbackCases';
import { apiClient } from '../api/client';
import { useAuth } from '../contexts/AuthContext';
import NotFoundPage from './NotFoundPage';
import './Page.css';

// Define interfaces for different page types
interface BasePageData {
  _id?: string;
  identifier: string;
  title: string;
  overview: ContentBlock[] | null;
  published?: boolean;
  updatedAt?: string;
}

interface CasePageData extends BasePageData {
  slug: string;
}

interface MainPageData extends BasePageData {
  identifier: 'main';
}

interface ClientsPageData extends BasePageData {
  identifier: 'clients';
}

type PageData = CasePageData | MainPageData | ClientsPageData;

const Page: React.FC = () => {
  const { caseId } = useParams<{ caseId: string }>();
  const location = useLocation();
  const { user } = useAuth();
  
  // State for the fetched page data, loading status, and errors
  const [pageData, setPageData] = useState<PageData | null>(null);
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);
  const [contentReady, setContentReady] = useState<boolean>(false);
  const [usingFallback, setUsingFallback] = useState<boolean>(false);

  // Determine page type based on route
  const pageType = useMemo(() => {
    if (location.pathname === '/') return 'main';
    if (location.pathname === '/clients') return 'clients';
    return 'case';
  }, [location.pathname]);

  useEffect(() => {
    const fetchPageData = async () => {
      setIsLoading(true);
      setError(null);
      setPageData(null);
      setUsingFallback(false);

      if (import.meta.env.DEV) {
        console.log(`Fetching data for ${pageType} page${user ? ' (authenticated)' : ' (unauthenticated)'}`);
      }

      try {
        let data: PageData | null = null;

        // Fetch data based on page type
        switch (pageType) {
          case 'main':
            data = await apiClient.getPage('main');
            break;
          case 'clients':
            data = await apiClient.getPage('clients');
            break;
          case 'case':
            if (!caseId) throw new Error('No case ID provided');
            data = await apiClient.getCase(caseId);
            break;
        }

        if (!data) {
          throw new Error(`No data available for ${pageType} page`);
        }

        // Basic validation of overview data
        if (data.overview && !Array.isArray(data.overview)) {
          if (import.meta.env.DEV) {
            console.warn('Fetched overview data is not an array, attempting to parse or fallback.');
          }
          data.overview = [];
        }

        setPageData(data);
        document.title = `${data.title} - Studio Paulides`;

      } catch (err: any) {
        console.error(`Error fetching ${pageType} page data:`, err);
        
        // Handle specific error cases
        if (err.message?.includes('404') || err.status === 404) {
          if (user) {
            setError(`${pageType === 'case' ? 'Case' : 'Page'} niet gevonden. Mogelijk is deze verwijderd of heeft de URL een typfout.`);
          } else {
            setError(`${pageType === 'case' ? 'Case' : 'Page'} niet gevonden. Als dit een draft pagina is, log dan in om deze te bekijken.`);
          }
        } else {
          setError(`Could not load ${pageType} page: ${err.message || 'Unknown error'}`);
        }

        // Use fallback data if available (only for cases)
        if (pageType === 'case' && caseId) {
          const fallbackData = getFallbackCase(caseId);
          if (fallbackData) {
            // Fallback data already has the correct type with identifier
            setPageData(fallbackData);
            setUsingFallback(true);
            document.title = `${fallbackData.title} - Studio Paulides`;
          }
        }
      } finally {
        setIsLoading(false);
        // Mark content as ready after a brief delay for smooth transition
        setTimeout(() => {
          setContentReady(true);
        }, 100);
      }
    };

    fetchPageData();
  }, [pageType, caseId, user]);

  // Memoize content analysis
  const contentAnalysis = useMemo(() => {
    if (!pageData?.overview) {
      return { hasTitleBlock: false, hasH1InContent: false, needsMainHeading: true };
    }
    
    const hasTitleBlock = pageData.overview.some(block => block.type === 'title');
    const firstTextBlock = pageData.overview.find(block => block.type === 'text') as any;
    const hasH1InContent = firstTextBlock && firstTextBlock.content?.includes('<h1');
    
    return {
      hasTitleBlock,
      hasH1InContent,
      needsMainHeading: !hasTitleBlock && !hasH1InContent
    };
  }, [pageData?.overview]);

  // Render loading state
  if (isLoading) {
    return (
      <main className="main-content-area">
        <article 
          className="content-section" 
          style={{ 
            paddingTop: 'var(--spacing-5)',
            paddingLeft: '1rem', 
            paddingRight: '1rem' 
          }} 
        >
          <div className="skeleton-loader">
            {/* Back button skeleton for case pages */}
            {pageType === 'case' && (
              <div style={{
                height: '2.5rem',
                backgroundColor: 'var(--color-z-30)',
                borderRadius: '4px',
                marginBottom: '1.5rem',
                width: '120px',
                animation: 'pulse 1.5s ease-in-out infinite alternate'
              }}></div>
            )}
            
            {/* Title skeleton */}
            <div className="skeleton-heading" style={{
              height: '3rem',
              backgroundColor: 'var(--color-z-30)',
              borderRadius: '8px',
              marginBottom: '2rem',
              width: '80%',
              animation: 'pulse 1.5s ease-in-out infinite alternate',
              animationDelay: '0.1s'
            }}></div>
            
            {/* Content blocks skeleton */}
            <div style={{
              display: 'flex',
              flexDirection: 'column',
              gap: '1.5rem'
            }}>
              {[1, 2, 3].map((i) => (
                <div key={i} style={{
                  height: '8rem',
                  backgroundColor: 'var(--color-z-30)',
                  borderRadius: '8px',
                  animation: 'pulse 1.5s ease-in-out infinite alternate',
                  animationDelay: `${i * 0.1}s`
                }}></div>
              ))}
            </div>
          </div>
          
          <style>{`
            @keyframes pulse {
              0% { opacity: 0.6; }
              100% { opacity: 1; }
            }
            
            @media (prefers-color-scheme: dark) {
              .skeleton-loader div {
                background-color: var(--color-z-90) !important;
              }
            }
          `}</style>
        </article>
      </main>
    );
  }

  // Render error state
  if (error) {
    // Check if this is a 404 error
    const is404Error = error.includes('404') || error.includes('niet gevonden') || error.includes('not found');
    
    if (is404Error) {
      return <NotFoundPage />;
    }
    
    return (
      <main className="main-content-area">
        <article 
          className="content-section" 
          style={{ 
            paddingTop: 'var(--spacing-5)',
            paddingLeft: '1rem', 
            paddingRight: '1rem',
            textAlign: 'center'
          }} 
        >
          <div className="error-state">
            <div style={{
              fontSize: '3rem',
              marginBottom: '1rem',
              opacity: 0.5
            }}>⚠️</div>
            <h1 className="main-heading" style={{ marginBottom: '1rem' }}>
              Er ging iets mis
            </h1>
            <p className="section-text" style={{ 
              marginBottom: '2rem',
              color: 'var(--color-z-70)'
            }}>
              We konden de pagina niet laden. Dit kan tijdelijk zijn door een verbindingsprobleem.
            </p>
            <div style={{ marginBottom: '2rem' }}>
              <button 
                onClick={() => window.location.reload()} 
                className="button button--primary"
                style={{ marginRight: '1rem' }}
              >
                Probeer opnieuw
              </button>
              <button 
                onClick={() => window.history.back()} 
                className="button button--secondary"
              >
                Ga terug
              </button>
            </div>
          </div>
        </article>
      </main>
    );
  }

  // Render content
  return (
    <main className="main-content-area">
      <article 
        className="content-section" 
        style={{ 
          paddingTop: 'var(--spacing-5)',
          paddingLeft: '1rem', 
          paddingRight: '1rem',
          opacity: contentReady ? 1 : 0.8,
          transform: contentReady ? 'translateY(0)' : 'translateY(5px)',
          transition: 'opacity 0.3s ease-out, transform 0.3s ease-out'
        }} 
      >
        {/* Back button for case pages */}
        {pageType === 'case' && <BackLink />}
        
        {/* Add main heading if not present in content blocks */}
        {contentAnalysis.needsMainHeading && (
          <h1 className="main-heading" style={{ marginBottom: '1.5rem' }}>
            {pageData?.title || 'Page'}
          </h1>
        )}
        
        {/* Render the content blocks */}
        <div className="content-blocks-container">
          {pageData?.overview?.map(block => renderBlock(block))}
        </div>
        
        {/* Development mode indicators */}
        {import.meta.env.DEV && (
          <>
            {usingFallback && (
              <div style={{
                position: 'fixed',
                bottom: '1rem',
                right: '1rem',
                background: 'rgba(255, 165, 0, 0.1)',
                border: '1px solid orange',
                borderRadius: '4px',
                padding: '0.5rem',
                fontSize: '0.75rem',
                color: 'orange',
                zIndex: 1000
              }}>
                Using fallback content
              </div>
            )}
            {error && (
              <div style={{
                position: 'fixed',
                bottom: '1rem',
                right: '1rem',
                background: 'rgba(255, 0, 0, 0.1)',
                border: '1px solid red',
                borderRadius: '4px',
                padding: '0.5rem',
                fontSize: '0.75rem',
                color: 'red',
                zIndex: 1000,
                maxWidth: '300px'
              }}>
                API Error: {error}
              </div>
            )}
          </>
        )}
      </article>
    </main>
  );
};

export default Page; 